@@ -7,7 +7,9 @@ def merge(
     input_dir: str = None,#typer.Option(None, help="Optional directory containing node and edge files"),
     edges: List[str] = None,#typer.Option(None, help="Optional list of edge files"),
     nodes: List[str] = None,#typer.Option(None, help="Optional list of node files"),
-    output_dir: str = "merged-output",#typer.Option("merge-output", help="Directory to output knowledge graph")
+    mapping: str = None,#typer.Option(None, help="Optional SSSOM mapping file")
+    output_dir: str = "merged-output",#typer.Option("merged-output", help="Directory to output knowledge graph")
+    merge_delimiter: str = "|",#typer.Option("|", help="Delimiter to use when merging categories and properties on duplicates")
     ):
 
     print(f"Merging KG files...\nName: {name} // input_dir: {input_dir} // nodes: {nodes} // edges: {edges} // output_dir: {output_dir}")
@@ -20,8 +22,12 @@ def merge(
         node_dfs = read_dfs(node_files)
         edge_dfs = read_dfs(edge_files)
 
+    mapping_df = None
+    if mapping is not None:
+        mapping_df = read_df()
+
     write(
         name=name,
-        kg=merge_kg(node_dfs=node_dfs, edge_dfs=edge_dfs),
+        kg=merge_kg(node_dfs=node_dfs, edge_dfs=edge_dfs, mapping=mapping_df, merge_delimiter=merge_delimiter),
         output_dir=output_dir
     )
